local animation = require("Models/animation")

local statics = require("statics")
local functions = require("functions")

local sprite = {}
sprite.__index = sprite

function sprite:new()
    local self = setmetatable({}, self)

    self.x = 0
    self.y = 0
    self.width = 0
    self.height = 0
    self.hflip = false
    self.vflip = false
    self.hscale = function(self)
        if self.hflip then
            return -statics.scale
        else
            return statics.scale
        end
    end
    self.vscale = function(self)
        if self.vflip then
            return -statics.scale
        else
            return statics.scale
        end
    end
    self.animated = false
    self.animations = {}
    self.vel = 
    {
        x = 0,
        y = 0,
    }
    self.rect = function(self)
        return 
        {
            x = self.x + self.vel.x,
            y = self.y + self.vel.y,
            width = self.width * statics.scale,
            height = self.height * statics.scale,
        }
    end

    return self
end

function sprite:update(dt)
    if self.animated then
        self.currentanim:update(dt)
    end

    self.x = self.x + self.vel.x
    self.y = self.y + self.vel.y

    self.vel.x = 0
    self.vel.y = 0
end

function sprite:draw()
    if self.animated then
        love.graphics.draw(self.currentanim.atlas, self.currentanim:getquad(), self.x, self.y, 0, self:hscale(), self:vscale(), 0, 0)
    else
        love.graphics.draw(self.texture, self.quad, self.x + 10 * functions.boolToInt(self.hflip) * statics.scale, self.y, 0, self:hscale(), self:vscale(), 0, 0)
    end
end

return sprite