local sprite = require("Sprites/sprite")
local player = require("Sprites/Entities/player")

local input = require("Models/input")

local inventory = require("Models/UI/inventory")

local area = require("Models/area")
local tileset = require("Models/tileset")
local tile = require("Sprites/tile")
local decoration = require("Sprites/decoration")

world = {}
world.__index = world

world.areas = {}
world.entities = {}

function world.load()
    world.entities = {}

    world.sandtileset = tileset:new(love.graphics.newImage("Assets/Graphics/Tilesets/sandtiles.png"), love.graphics.newImage("Assets/Graphics/Tilesets/sanddecorations.png"), 16, 16)

    world.loadTilemap()

    world.decorations = 
    {
        decoration:new(world.sandtileset, 2, 2, 2),
        decoration:new(world.sandtileset, 4, 6, 1),
    }

    world.area1 = area:new(world.tiles, world.decorations)

    world.entities.player = player:new()

    input1 = input:new("r", "f", "d", "g", "t")

    world.entities.player.texture = love.graphics.newImage("Assets/Graphics/Entities/Player.png")
    world.entities.player.quad = functions.setDefaultQuad(world.entities.player.texture)
    world.entities.player.input = input1.playerinput
    world.entities.player.inventory = inventory:new()

    world.entities.player.width = 10
    world.entities.player.height = 20

    world.areas.area1 = world.area1
    world.currentarea = world.area1
    
    --world.entities.player.tiles = world.currentarea.tilemap.tiles
    world.entities.player.tiles = {}
end

function world.update(dt)
    input.update()

    for k, v in pairs(world.entities) do
        v:update(dt)
    end
end

function world.draw()
    world.currentarea:draw()

    for k, v in pairs(world.entities) do
        v:draw()
    end
end

function world.loadTilemap()
    world.tiles = 
    {
        tile:new(world.sandtileset, 0, 0, 14),
        tile:new(world.sandtileset, 1, 0, 14),
        tile:new(world.sandtileset, 2, 0, 14),
        tile:new(world.sandtileset, 3, 0, 14),
        tile:new(world.sandtileset, 4, 0, 14),
        tile:new(world.sandtileset, 5, 0, 14),
        tile:new(world.sandtileset, 6, 0, 14),
        tile:new(world.sandtileset, 7, 0, 14),
        tile:new(world.sandtileset, 8, 0, 14),
        tile:new(world.sandtileset, 9, 0, 14),
        tile:new(world.sandtileset, 10, 0, 14),
        tile:new(world.sandtileset, 11, 0, 14),
        tile:new(world.sandtileset, 12, 0, 14),
        tile:new(world.sandtileset, 13, 0, 14),
        tile:new(world.sandtileset, 14, 0, 14),
        tile:new(world.sandtileset, 15, 0, 14),
        tile:new(world.sandtileset, 16, 0, 14),
        tile:new(world.sandtileset, 17, 0, 14),
        tile:new(world.sandtileset, 18, 0, 14),
        tile:new(world.sandtileset, 19, 0, 14),
        tile:new(world.sandtileset, 20, 0, 14),
        tile:new(world.sandtileset, 0, 1, 14),
        tile:new(world.sandtileset, 1, 1, 1),
        tile:new(world.sandtileset, 2, 1, 2),
        tile:new(world.sandtileset, 3, 1, 2),
        tile:new(world.sandtileset, 4, 1, 2),
        tile:new(world.sandtileset, 5, 1, 2),
        tile:new(world.sandtileset, 6, 1, 2),
        tile:new(world.sandtileset, 7, 1, 3),
        tile:new(world.sandtileset, 8, 1, 1),
        tile:new(world.sandtileset, 9, 1, 2),
        tile:new(world.sandtileset, 10, 1, 2),
        tile:new(world.sandtileset, 11, 1, 2),
        tile:new(world.sandtileset, 12, 1, 2),
        tile:new(world.sandtileset, 13, 1, 3),
        tile:new(world.sandtileset, 14, 1, 14),
        tile:new(world.sandtileset, 15, 1, 1),
        tile:new(world.sandtileset, 16, 1, 2),
        tile:new(world.sandtileset, 17, 1, 3),
        tile:new(world.sandtileset, 18, 1, 14),
        tile:new(world.sandtileset, 19, 1, 14),
        tile:new(world.sandtileset, 20, 1, 14),
        tile:new(world.sandtileset, 0, 2, 14),
        tile:new(world.sandtileset, 1, 2, 4),
        tile:new(world.sandtileset, 2, 2, 5),
        tile:new(world.sandtileset, 3, 2, 5),
        tile:new(world.sandtileset, 4, 2, 5),
        tile:new(world.sandtileset, 5, 2, 5),
        tile:new(world.sandtileset, 6, 2, 5),
        tile:new(world.sandtileset, 7, 2, 6),
        tile:new(world.sandtileset, 8, 2, 4),
        tile:new(world.sandtileset, 9, 2, 5),
        tile:new(world.sandtileset, 10, 2, 5),
        tile:new(world.sandtileset, 11, 2, 5),
        tile:new(world.sandtileset, 12, 2, 5),
        tile:new(world.sandtileset, 13, 2, 6),
        tile:new(world.sandtileset, 14, 2, 14),
        tile:new(world.sandtileset, 15, 2, 4),
        tile:new(world.sandtileset, 16, 2, 5),
        tile:new(world.sandtileset, 17, 2, 6),
        tile:new(world.sandtileset, 18, 2, 14),
        tile:new(world.sandtileset, 19, 2, 14),
        tile:new(world.sandtileset, 20, 2, 14),
        tile:new(world.sandtileset, 0, 3, 14),
        tile:new(world.sandtileset, 1, 3, 4),
        tile:new(world.sandtileset, 2, 3, 5),
        tile:new(world.sandtileset, 3, 3, 10),
        tile:new(world.sandtileset, 4, 3, 8),
        tile:new(world.sandtileset, 5, 3, 8),
        tile:new(world.sandtileset, 6, 3, 8),
        tile:new(world.sandtileset, 7, 3, 9),
        tile:new(world.sandtileset, 8, 3, 4),
        tile:new(world.sandtileset, 9, 3, 5),
        tile:new(world.sandtileset, 10, 3, 10),
        tile:new(world.sandtileset, 11, 3, 8),
        tile:new(world.sandtileset, 12, 3, 8),
        tile:new(world.sandtileset, 13, 3, 9),
        tile:new(world.sandtileset, 14, 3, 14),
        tile:new(world.sandtileset, 15, 3, 4),
        tile:new(world.sandtileset, 16, 3, 5),
        tile:new(world.sandtileset, 17, 3, 6),
        tile:new(world.sandtileset, 18, 3, 14),
        tile:new(world.sandtileset, 19, 3, 14),
        tile:new(world.sandtileset, 20, 3, 14),
        tile:new(world.sandtileset, 0, 4, 14),
        tile:new(world.sandtileset, 1, 4, 4),
        tile:new(world.sandtileset, 2, 4, 5),
        tile:new(world.sandtileset, 3, 4, 6),
        tile:new(world.sandtileset, 4, 4, 14),
        tile:new(world.sandtileset, 5, 4, 1),
        tile:new(world.sandtileset, 6, 4, 2),
        tile:new(world.sandtileset, 7, 4, 3),
        tile:new(world.sandtileset, 8, 4, 4),
        tile:new(world.sandtileset, 9, 4, 5),
        tile:new(world.sandtileset, 10, 4, 6),
        tile:new(world.sandtileset, 11, 4, 1),
        tile:new(world.sandtileset, 12, 4, 2),
        tile:new(world.sandtileset, 13, 4, 3),
        tile:new(world.sandtileset, 14, 4, 14),
        tile:new(world.sandtileset, 15, 4, 7),
        tile:new(world.sandtileset, 16, 4, 8),
        tile:new(world.sandtileset, 17, 4, 9),
        tile:new(world.sandtileset, 18, 4, 14),
        tile:new(world.sandtileset, 19, 4, 14),
        tile:new(world.sandtileset, 20, 4, 14),
        tile:new(world.sandtileset, 0, 5, 14),
        tile:new(world.sandtileset, 1, 5, 4),
        tile:new(world.sandtileset, 2, 5, 5),
        tile:new(world.sandtileset, 3, 5, 6),
        tile:new(world.sandtileset, 4, 5, 14),
        tile:new(world.sandtileset, 5, 5, 4),
        tile:new(world.sandtileset, 6, 5, 5),
        tile:new(world.sandtileset, 7, 5, 6),
        tile:new(world.sandtileset, 8, 5, 7),
        tile:new(world.sandtileset, 9, 5, 8),
        tile:new(world.sandtileset, 10, 5, 9),
        tile:new(world.sandtileset, 11, 5, 4),
        tile:new(world.sandtileset, 12, 5, 5),
        tile:new(world.sandtileset, 13, 5, 6),
        tile:new(world.sandtileset, 14, 5, 1),
        tile:new(world.sandtileset, 15, 5, 2),
        tile:new(world.sandtileset, 16, 5, 2),
        tile:new(world.sandtileset, 17, 5, 3),
        tile:new(world.sandtileset, 18, 5, 14),
        tile:new(world.sandtileset, 19, 5, 14),
        tile:new(world.sandtileset, 20, 5, 14),
        tile:new(world.sandtileset, 0, 6, 14),
        tile:new(world.sandtileset, 1, 6, 4),
        tile:new(world.sandtileset, 2, 6, 5),
        tile:new(world.sandtileset, 3, 6, 12),
        tile:new(world.sandtileset, 4, 6, 2),
        tile:new(world.sandtileset, 5, 6, 13),
        tile:new(world.sandtileset, 6, 6, 5),
        tile:new(world.sandtileset, 7, 6, 12),
        tile:new(world.sandtileset, 8, 6, 2),
        tile:new(world.sandtileset, 9, 6, 2),
        tile:new(world.sandtileset, 10, 6, 2),
        tile:new(world.sandtileset, 11, 6, 13),
        tile:new(world.sandtileset, 12, 6, 5),
        tile:new(world.sandtileset, 13, 6, 12),
        tile:new(world.sandtileset, 14, 6, 13),
        tile:new(world.sandtileset, 15, 6, 5),
        tile:new(world.sandtileset, 16, 6, 5),
        tile:new(world.sandtileset, 17, 6, 6),
        tile:new(world.sandtileset, 18, 6, 14),
        tile:new(world.sandtileset, 19, 6, 14),
        tile:new(world.sandtileset, 20, 6, 14),
        tile:new(world.sandtileset, 0, 7, 14),
        tile:new(world.sandtileset, 1, 7, 4),
        tile:new(world.sandtileset, 2, 7, 5),
        tile:new(world.sandtileset, 3, 7, 5),
        tile:new(world.sandtileset, 4, 7, 5),
        tile:new(world.sandtileset, 5, 7, 5),
        tile:new(world.sandtileset, 6, 7, 5),
        tile:new(world.sandtileset, 7, 7, 5),
        tile:new(world.sandtileset, 8, 7, 5),
        tile:new(world.sandtileset, 9, 7, 5),
        tile:new(world.sandtileset, 10, 7, 5),
        tile:new(world.sandtileset, 11, 7, 5),
        tile:new(world.sandtileset, 12, 7, 5),
        tile:new(world.sandtileset, 13, 7, 5),
        tile:new(world.sandtileset, 14, 7, 5),
        tile:new(world.sandtileset, 15, 7, 5),
        tile:new(world.sandtileset, 16, 7, 5),
        tile:new(world.sandtileset, 17, 7, 6),
        tile:new(world.sandtileset, 18, 7, 14),
        tile:new(world.sandtileset, 19, 7, 14),
        tile:new(world.sandtileset, 20, 7, 14),
        tile:new(world.sandtileset, 0, 8, 14),
        tile:new(world.sandtileset, 1, 8, 7),
        tile:new(world.sandtileset, 2, 8, 8),
        tile:new(world.sandtileset, 3, 8, 8),
        tile:new(world.sandtileset, 4, 8, 8),
        tile:new(world.sandtileset, 5, 8, 8),
        tile:new(world.sandtileset, 6, 8, 8),
        tile:new(world.sandtileset, 7, 8, 8),
        tile:new(world.sandtileset, 8, 8, 8),
        tile:new(world.sandtileset, 9, 8, 8),
        tile:new(world.sandtileset, 10, 8, 8),
        tile:new(world.sandtileset, 11, 8, 8),
        tile:new(world.sandtileset, 12, 8, 8),
        tile:new(world.sandtileset, 13, 8, 8),
        tile:new(world.sandtileset, 14, 8, 8),
        tile:new(world.sandtileset, 15, 8, 8),
        tile:new(world.sandtileset, 16, 8, 8),
        tile:new(world.sandtileset, 17, 8, 9),
        tile:new(world.sandtileset, 18, 8, 14),
        tile:new(world.sandtileset, 19, 8, 14),
        tile:new(world.sandtileset, 20, 8, 14),
        tile:new(world.sandtileset, 0, 9, 14),
        tile:new(world.sandtileset, 1, 9, 14),
        tile:new(world.sandtileset, 2, 9, 14),
        tile:new(world.sandtileset, 3, 9, 14),
        tile:new(world.sandtileset, 4, 9, 14),
        tile:new(world.sandtileset, 5, 9, 14),
        tile:new(world.sandtileset, 6, 9, 14),
        tile:new(world.sandtileset, 7, 9, 14),
        tile:new(world.sandtileset, 8, 9, 14),
        tile:new(world.sandtileset, 9, 9, 14),
        tile:new(world.sandtileset, 10, 9, 14),
        tile:new(world.sandtileset, 11, 9, 14),
        tile:new(world.sandtileset, 12, 9, 14),
        tile:new(world.sandtileset, 13, 9, 14),
        tile:new(world.sandtileset, 14, 9, 14),
        tile:new(world.sandtileset, 15, 9, 14),
        tile:new(world.sandtileset, 16, 9, 14),
        tile:new(world.sandtileset, 17, 9, 14),
        tile:new(world.sandtileset, 18, 9, 14),
        tile:new(world.sandtileset, 19, 9, 14),
        tile:new(world.sandtileset, 20, 9, 14),
        tile:new(world.sandtileset, 0, 10, 14),
        tile:new(world.sandtileset, 1, 10, 14),
        tile:new(world.sandtileset, 2, 10, 14),
        tile:new(world.sandtileset, 3, 10, 14),
        tile:new(world.sandtileset, 4, 10, 14),
        tile:new(world.sandtileset, 5, 10, 14),
        tile:new(world.sandtileset, 6, 10, 14),
        tile:new(world.sandtileset, 7, 10, 14),
        tile:new(world.sandtileset, 8, 10, 14),
        tile:new(world.sandtileset, 9, 10, 14),
        tile:new(world.sandtileset, 10, 10, 14),
        tile:new(world.sandtileset, 11, 10, 14),
        tile:new(world.sandtileset, 12, 10, 14),
        tile:new(world.sandtileset, 13, 10, 14),
        tile:new(world.sandtileset, 14, 10, 14),
        tile:new(world.sandtileset, 15, 10, 14),
        tile:new(world.sandtileset, 16, 10, 14),
        tile:new(world.sandtileset, 17, 10, 14),
        tile:new(world.sandtileset, 18, 10, 14),
        tile:new(world.sandtileset, 19, 10, 14),
        tile:new(world.sandtileset, 20, 10, 14),
    }
end

return world